@@ -2,9 +2,10 @@ from typing import Tuple, Union
 
 import fiona
 import numpy as np
+import rasterio
 from affine import Affine
+from osgeo import gdal
 from rasterio import features
-from rasterio.crs import CRS
 from rasterio.features import shapes
 from rasterio.transform import from_origin, rowcol, xy
 from rasterio.warp import (Resampling, aligned_target,
@@ -40,8 +41,10 @@ def translate_profile(profile: dict,
     ----------
     profile : dict
         Rasterio profile
-    shift : float
-        Number of pixels to translate by
+    x_shift : float
+        Number of pixels to translate in the x direction by
+    y_shift : float
+        Number of pixels to translate in the y direction by
 
     Returns
     -------
@@ -49,7 +52,6 @@ def translate_profile(profile: dict,
         Rasterio profile with transform shifted
     """
     transform = profile['transform']
-
     new_origin = transform * (x_shift, y_shift)
     new_transform = Affine.translation(*new_origin)
     new_transform *= transform.scale(transform.a,
@@ -61,6 +63,65 @@ def translate_profile(profile: dict,
     return p_new
 
 
+def gdal_translate_profile(filepath: str,
+                           x_shift: float,
+                           y_shift: float) -> Tuple[np.ndarray, dict]:
+    """Shift profile
+
+    Parameters
+    ----------
+    filepath : str
+        dataset file to update
+    x_shift : float
+        Number of pixels to translate in the x direction by
+    y_shift : float
+        Number of pixels to translate in the y direction by
+
+
+    Returns
+    -------
+    np.ndarray, dict
+        Rasterio profile and array with transform shifted
+    """
+
+    # open dataset with update permission
+    ds = gdal.Open(filepath, gdal.GA_Update)
+    # get the geotransform as a tuple of 6
+    gt = ds.GetGeoTransform()
+    # unpack geotransform into variables
+    x_tl, x_res, dx_dy, y_tl, dy_dx, y_res = gt
+
+    # compute shift of 1 pixel RIGHT in X direction
+    shift_x = x_shift * x_res
+    # compute shift of 2 pixels UP in Y direction
+    # y_res likely negative, because Y decreases with increasing Y index
+    shift_y = y_shift * y_res
+
+    # make new geotransform
+    gt_update = (x_tl + shift_x, x_res, dx_dy, y_tl + shift_y, dy_dx, y_res)
+    # assign new geotransform to raster
+    ds.SetGeoTransform(gt_update)
+    # ensure changes are committed
+    ds.FlushCache()
+    del ds
+
+    # Update VRT
+    gdal.BuildVRT(filepath+'.vrt',
+                  filepath,
+                  options=gdal.BuildVRTOptions(options=['-overwrite']))
+
+    with rasterio.open(filepath) as read_dataset:
+        dat_arr = read_dataset.read(1)
+        profile = read_dataset.profile
+
+    # update geotrans
+    trans_list = gdal.Open(filepath).GetGeoTransform()
+    transform_cropped = Affine.from_gdal(*trans_list)
+    profile['transform'] = transform_cropped
+
+    return dat_arr, profile
+
+
 def get_geopandas_features_from_array(arr: np.ndarray,
                                       transform: Affine,
                                       label_name: str = 'label',
@@ -103,7 +164,7 @@ def get_geopandas_features_from_array(arr: np.ndarray,
                                mask=~mask,
                                transform=transform,
                                connectivity=connectivity))
-    geo_features = list({'properties': {label_name: (value)},
+    geo_features = list({'properties': {label_name: value},
                          'geometry': geometry}
                         for i, (geometry, value) in enumerate(feature_list))
     return geo_features
@@ -143,12 +204,10 @@ def polygonize_array_to_shapefile(arr: np.ndarray,
     dtype = str(arr.dtype)
     if 'int' in dtype or 'bool' in dtype:
         arr = arr.astype('int32')
-        dtype = 'int32'
         dtype_for_shape_file = 'int'
 
     if 'float' in dtype:
         arr = arr.astype('float32')
-        dtype = 'float32'
         dtype_for_shape_file = 'float'
 
     crs = profile['crs']
@@ -352,7 +411,7 @@ def get_bounds_dict(profile: dict) -> dict:
     return bounds_dict
 
 
-def reproject_profile_to_new_crs(src_profile: dict, dst_crs: CRS,
+def reproject_profile_to_new_crs(src_profile: dict, dst_crs: str,
                                  target_resolution: Union[float, int] = None)\
                                          -> dict:
     """
